@@ -1,12 +1,12 @@
 package Glib::Object::Introspection::Install::Files;
 
 $self = {
-          'deps' => [
-                      'Glib'
-                    ],
           'typemaps' => [],
           'libs' => '-L/usr/local/lib -lgirepository-1.0 -lgobject-2.0 -lglib-2.0 -lintl -L/usr/local/lib -Wl,-E -pthread -lgmodule-2.0 -lglib-2.0 -lintl -L/usr/local/lib -pthread -lffi',
-          'inc' => '-I/usr/local/include/gobject-introspection-1.0 -pthread -I/usr/local/include -I/usr/local/include/glib-2.0 -I/usr/local/lib/glib-2.0/include -pthread -I/usr/local/include/glib-2.0 -I/usr/local/lib/glib-2.0/include -I/usr/local/include -I/usr/local/include'
+          'inc' => '-I/usr/local/include/gobject-introspection-1.0 -pthread -I/usr/local/include -I/usr/local/include/glib-2.0 -I/usr/local/lib/glib-2.0/include -pthread -I/usr/local/include/glib-2.0 -I/usr/local/lib/glib-2.0/include -I/usr/local/include -I/usr/local/include',
+          'deps' => [
+                      'Glib'
+                    ]
         };
 
 
